@@ -23,11 +23,19 @@ extern int D_alloc;
 
 extern char *nbytes();
 
-#if	defined(__alpha) /* .. and other 64 bit machines ? */
-#define NALIGN		8	/* bytesize of largest type needing alignment */
+#if defined(sparc) || defined(__sparc__)
+#define NALIGN	8	/* SPARC wants doubles at 8-byte boundary, always!
+			   The ZMailer does not use floating point, but
+			   that is another story.. */
 #else
-#define	NALIGN		4	/* bytesize of largest type needing alignment */
+#if	SIZEOF_VOID_P == 8 /* various 64-bit machines */
+#define NALIGN	8	/* bytesize of largest type needing alignment */
+#else			/* So, perhaps it is mere 32-bit ? */
+#define	NALIGN	4	/* bytesize of largest type needing alignment */
 #endif
+#endif
+static void moremem __((const u_int, const memtypes));
+
 #if	NALIGN == 2 || NALIGN == 4 || NALIGN == 8 || NALIGN == 16
 /* if NALIGN is a power of 2, the next line will do ok */
 #define	ALIGN(X) (char *)(((u_long)((char *)(X) + (NALIGN-1))) & ~(NALIGN-1))
@@ -70,17 +78,17 @@ static u_long stackmem = 0;	/* bitmap: intend to use block memory as a stack */
 /*
  * Inline macros for allocating memory
  */
-#define	GETALIGNED(n,i,cp)	if (blockinuse[(i)] == NULL || \
-			    blockinuse[(i)]->cur+(n) >= blockinuse[(i)]->endp) \
+#define	GETALIGNED(n,i,cp)	if (blockinuse[(int)(i)] == NULL || \
+			    blockinuse[(int)(i)]->cur+(n) >= blockinuse[(int)(i)]->endp) \
 					moremem((n), (i)); \
-				(cp) = ALIGN(blockinuse[(i)]->cur); \
-				blockinuse[(i)]->cur = ((char *)(cp)) + (n)
+				(cp) = ALIGN(blockinuse[(int)(i)]->cur); \
+				blockinuse[(int)(i)]->cur = ((char *)(cp)) + (n)
 
-#define	GETMEMORY(n,i,cp)	if (blockinuse[(i)] == NULL || \
-			    blockinuse[(i)]->cur+(n) >= blockinuse[(i)]->endp) \
+#define	GETMEMORY(n,i,cp)	if (blockinuse[(int)(i)] == NULL || \
+			    blockinuse[(int)(i)]->cur+(n) >= blockinuse[(int)(i)]->endp) \
 					moremem((n), (i)); \
-				(cp) = blockinuse[(i)]->cur; \
-				blockinuse[(i)]->cur += (n)
+				(cp) = blockinuse[(int)(i)]->cur; \
+				blockinuse[(int)(i)]->cur += (n)
 
 
 /*
