@@ -3,13 +3,17 @@
  *	This will be free software, but only when it is finished.
  *
  *	Also Guy Middleton, and Matti Aarnio have hacked this piece -- 1993
+ *
+ *	In 1996 Matti Aarnio <mea@nic.funet.fi> converted this to GNU autoconf
+ *
  */
 
+/* XXX: Some of these routines have memory leakage! */
 
 /*LINTLIBRARY*/
 
-#include <stdio.h>
 #include "hostenv.h"
+#include <stdio.h>
 #include <errno.h>
 #include <sys/param.h>
 #include <sys/stat.h>
@@ -18,44 +22,35 @@
 #include "mail.h"
 
 
-#ifdef	AF_INET
-
-#ifdef	USE_NFS
-
-#ifdef	USE_ULTRIXGETMNT
+#ifdef	MOUNTED_GETMNT /* DEC Ultrix */
 #include <sys/param.h>
 #include <sys/mount.h>
 #endif
 
-#ifdef	USE_OSFGETMNT
+#ifdef	MOUNTED_GETMNTINFO /* DEC OSF/1 */
 #include <sys/types.h>
 #include <sys/mount.h>
 #endif
 
-#ifdef	USE_SUNGETMNT
-#ifdef	USE_MNTTAB
+#ifdef MOUNTED_GETMNTENT2
 #include <sys/mnttab.h>
 #include <sys/mntent.h>
 #define	MNTTYPE	struct mnttab
-#else
+#endif
+
+#ifdef MOUNTED_GETMNTENT1
 #include <mntent.h>
 #define	MNTTYPE	struct mntent
 #endif
-#endif /* USE_SUNGETMNT */
 
-#ifdef	USE_SVR4MNTENT	/* Solaris, __svr4__ */
-#include <sys/mnttab.h>
-#include <sys/mntent.h>
-#define	MNTTYPE	struct mnttab
-#endif /* USE_SVR4MNTENT */
-
-#ifdef USE_POSIXMNTENT
-#include <mntent.h>
-#define MNTTYPE struct mntent
+#ifdef MOUNTED_VMOUNT		/* AIX */
+#include <sys/vfs.h>
+#include <fshelp.h>
 #endif
 
-
+#ifndef strchr
 extern char *strchr();
+#endif
 
 /* Sort of 'forward' definition */
 static char	*getmntpt();
@@ -65,7 +60,7 @@ static char	*getmntpt();
  * Given a name like /usr/src/etc/foo.c returns the mount point
  * for the file system it lives in, or NULL in case of any error.
  */
-#ifdef USE_ULTRIXGETMNT
+#ifdef MOUNTED_GETMNT /* Ultrix */
 static char *
 getmntpt(file, dir)
 	char	*file, **dir;
@@ -92,7 +87,7 @@ getmntpt(file, dir)
 }
 #endif
 
-#ifdef USE_OSFGETMNT
+#ifdef MOUNTED_GETMNTINFO /* DEC OSF/1 */
 static char *
 getmntpt(file, dir)
 	char	*file, **dir;
@@ -125,7 +120,7 @@ getmntpt(file, dir)
 }
 #endif
 
-#ifdef USE_SUNGETMNT
+#if defined(MOUNTED_GETMNTENT1) || defined(MOUNTED_GETMNTENT2)
 static char *
 getmntpt(file, dir)
 	char	*file, **dir;
@@ -139,7 +134,7 @@ getmntpt(file, dir)
 		perror(file);
 		return(NULL);
 	}
-#ifdef	USE_MNTTAB
+#ifdef	MOUNTED_GETMNTENT2
 	mnt = &rmnt;
 	if ((mntp = fopen(MNTTAB, "r")) == NULL) {
 		perror(MNTTAB);
@@ -156,7 +151,7 @@ getmntpt(file, dir)
 		}
 	}
 	fclose(mntp);
-#else
+#else /* MOUNTED_GETMNTENT1 */
 	if ((mntp = setmntent(MOUNTED, "r")) == NULL) {
 		perror(MOUNTED);
 		return(NULL);
@@ -177,85 +172,90 @@ getmntpt(file, dir)
 	return NULL;
 }
 #endif
-#endif	/* USE_NFS */
-
-#ifdef	USE_SVR4MNTENT /* Solaris / SysVR4 */
-static char *
-getmntpt(file, dir)
-	char	*file, **dir;
-{
-	FILE	*mntp;
-	MNTTYPE	*mnt;
-	static MNTTYPE	rmnt;
-	struct stat	filestat, dirstat;
-
-	if (stat(file, &filestat) < 0) {
-		perror(file);
-		return(NULL);
-	}
-
-	mnt = &rmnt;
-	if ((mntp = fopen(MNTTAB, "r")) == NULL) {
-		perror(MNTTAB);
-		return(NULL);
-	}
-	while (getmntent(mntp, mnt) == 0) {
-		if (strcmp(mnt->mnt_fstype, MNTTYPE_SWAP) == 0)
-			continue;
-		if ((stat(mnt->mnt_mountp, &dirstat) >= 0) &&
-		   (filestat.st_dev == dirstat.st_dev)) {
-			fclose(mntp);
-			*dir = mnt->mnt_mountp;
-			return mnt->mnt_special;
-		}
-	}
-	fclose(mntp);
-	return NULL;
-}
-#endif /* USE_SVR4MNTENT */
-
-
-#ifdef USE_POSIXMNTENT
-static char *
-getmntpt(file, dir)
-	char	*file, **dir;
-{
-	FILE	*mntp;
-	MNTTYPE	*mnt;
-	static MNTTYPE	rmnt;
-	struct stat	filestat, dirstat;
-
-	if (stat(file, &filestat) < 0) {
-		perror(file);
-		return(NULL);
-	}
-	if ((mntp = setmntent(MOUNTED, "r")) == NULL) {
-		perror(MOUNTED);
-		return(NULL);
-	}
-	while ((mnt = getmntent(mntp)) != 0) {
-		if (strcmp(mnt->mnt_type, MNTTYPE_IGNORE) == 0 ||
-		    strcmp(mnt->mnt_type, MNTTYPE_SWAP) == 0)
-			continue;
-		if ((stat(mnt->mnt_dir, &dirstat) >= 0) &&
-		   (filestat.st_dev == dirstat.st_dev)) {
-			endmntent(mntp);
-			*dir = mnt->mnt_dir;
-			return mnt->mnt_fsname;
-		}
-	}
-	endmntent(mntp);
-	return NULL;
-}
-#endif	/* USE_POSIXMNTENT */
 
+#if defined(MOUNTED_VMOUNT) /* AIX */
 
+/* Much of the following code is from GNU fileutils 3.13 */
+
+char *
+whathost(file)
+	char	*file;
+{
+	struct stat  dirstat, statb;
+	int bufsize;
+	char *entries, *thisent;
+	struct vmount *vmp;
+	char *dir, *host;
+
+#ifndef	MAXHOSTNAMELEN
+#define	MAXHOSTNAMELEN 64
+#endif	/* MAXHOSTNAMELEN */
+	static char	hostname[MAXHOSTNAMELEN+1];
+
+	/* Stat the file, is it a regular file, or a directory ? */
+	if (stat(file, &statb) < 0)
+		return NULL;
+	if (statb.st_mode & S_IFMT & (S_IFREG|S_IFDIR) == 0)
+	  return NULL;
+
+	/* Ask how many bytes to allocate for the mounted filesystem info.  */
+	mntctl (MCTL_QUERY, sizeof bufsize, (struct vmount *) &bufsize);
+#ifdef USE_ALLOCA
+	entries = alloca (bufsize);
+#else
+	entries = malloc (bufsize);
+	if (entries == NULL) return NULL; /* Ah well... */
+#endif
+	
+	/* Get the list of mounted filesystems.  */
+	mntctl (MCTL_QUERY, bufsize, (struct vmount *) entries);
+
+	vmp = NULL;
+	for (thisent = entries; thisent < entries + bufsize;
+	     thisent += vmp->vmt_length) {
+	  
+	  vmp  = (struct vmount *) thisent;
+	  if (vmp->vmt_flags == -1) break;
+
+	  dir  = thisent + vmp->vmt_data[VMT_STUB].vmt_off;
+
+	  /* Stat it;  Is it at same device as the file/dir ? */
+	  if (stat(dir,&dirstat) < 0 ||
+	      dirstat.st_dev != statb.st_dev)
+	    continue;
+
+	  /* Now the mount-point device does match with the file device;
+	     we know the mount-point where our file is located at! */
+
+	  if (vmp->vmt_flags & MNT_REMOTE) {
+	    /* A remote system! Return the hostname */
+	    host = thisent + vmp->vmt_data[VMT_HOSTNAME].vmt_off;
+	    strncpy(hostname,host,sizeof(hostname));
+	    hostname[sizeof(hostname)-1] = 0;
+#ifndef USE_ALLOCA
+	    free(entries);
+#endif
+	    return hostname;
+	  } else {
+#ifndef USE_ALLOCA
+	    free(entries);
+#endif
+	    return "localhost";
+	  }
+	}
+
+#ifndef USE_ALLOCA
+	free(entries);
+#endif
+	return NULL;
+}
+
+#else	/* Not AIX -- all other systems .. */
 
 char *
 whathost(file)
 	char	*file;
 {
-#ifdef	USE_NFS
 	struct stat	statb;
 	char		*mnt, *cp, *dir;
 #ifndef	MAXHOSTNAMELEN
@@ -275,17 +275,6 @@ whathost(file)
 		return hostname;
 	}
 	return NULL;
-#else	/* !USE_NFS */
-	return "localhost";
-#endif	/* USE_NFS */
 }
 
-#else	/* !AF_INET */
-
-char *
-whathost(file)
-	char	*file;
-{
-	return "localhost";
-}
-#endif	/* AF_INET */
+#endif
