@@ -58,6 +58,7 @@ static char sccsid[] = "@(#)gethostnamadr.c	8.1 (Berkeley) 6/4/93";
 static char rcsid[] = "$Id: gethnamaddr.c,v 8.16 1996/06/26 23:17:26 vixie Exp $";
 #endif /* LIBC_SCCS and not lint */
 
+#include <sys/types.h>
 #include <sys/param.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
@@ -89,7 +90,7 @@ static char rcsid[] = "$Id: gethnamaddr.c,v 8.16 1996/06/26 23:17:26 vixie Exp $
 #ifdef SPRINTF_CHAR
 # define SPRINTF(x) strlen(sprintf/**/x)
 #else
-# define SPRINTF(x) sprintf x
+# define SPRINTF(x) ((size_t)(sprintf x))
 #endif
 
 #define	MAXALIASES	35
