@@ -69,9 +69,11 @@ static char rcsid[] = "$Id: res_send.c,v 8.8 1996/05/09 05:59:13 vixie Exp $";
  * Send query to name server and wait for reply.
  */
 
+#include <sys/types.h>
 #include <sys/param.h>
 #include <sys/time.h>
 #include <sys/socket.h>
+#include <sys/select.h>
 #include <sys/uio.h>
 #include <netinet/in.h>
 #include "arpa/nameser.h"
