@@ -59,7 +59,9 @@ extern char *path_hash();
 extern char *prepath();
 extern char *strerror();
 extern char *strsignal();
+#ifndef strchr
 extern char *strchr();
+#endif
 extern int errno;
 extern int eval();
 extern int loadeval();
@@ -216,7 +218,7 @@ sh_setf(avl, il)
 	struct conscell *avl, *il;
 {
 	struct conscell *place, *value, *tmp = NULL;
-	int oval = stickymem;
+	memtypes oval = stickymem;
 
 	/*
 	 * The `place' argument to setf should NOT be malloc'ed stuff,
@@ -336,7 +338,7 @@ sh_get(avl, il)
 		}
 	}
 	if (plist) {
-		int oval = stickymem;
+		memtypes oval = stickymem;
 
 		/* plist is now s_last(cadr(v_find(key->string))) */
 		cdr(plist) = copycell(key);
@@ -892,7 +894,8 @@ sh_set(argc, argv)
 	int argc;
 	char *argv[];
 {
-	int n, i, oval;
+	int n, i;
+	memtypes oval;
 	char **kk, *cp, *ep;
 	struct conscell *d, *pd = NULL, *scope, *tmp;
 
