@@ -11,7 +11,11 @@
 
 #include "hostenv.h"
 #include <stdio.h>
-#include <varargs.h>
+#ifdef HAVE_STDARG_H
+# include <stdarg.h>
+#else
+# include <varargs.h>
+#endif
 #include <fcntl.h>
 #include <sys/file.h>
 #include "shconfig.h"
@@ -20,8 +24,8 @@ extern int vsiodoprnt();
 extern int cvt();
 extern double modf();
 extern char *exponent(), *round();
-#ifndef __STDC__
-extern int printf();
+#if !defined(__STDC__) && !defined(_AIX)
+ extern int printf();
 #endif
 
 struct siobuf *siofds[MAXNFILE];	/* string buffers */
@@ -48,7 +52,11 @@ int std_puts(s) char *s; { return puts(s); }
 
 int std_fputs(s, fp) char *s; FILE *fp; { return fputs(s, fp); }
 
-int (*std_printf)() = (int (*)())printf;
+#ifdef HAVE_STDARG_H
+int (*std_printf) __((char *fmt, ...)) = (int (*) __((char *fmt, ...)))printf;
+#else
+int (*std_printf) __((/*char *fmt, ...*/)) = (int (*) __((/* char *fmt, ... */)))printf;
+#endif
 
 int std_fread(b,s,n,fp) char *b; int s, n; FILE *fp;{ return fread(b,s,n,fp); }
 
@@ -157,17 +165,25 @@ vfprintf(fp, fmt, ap)
 #endif	/* !HAVE_VPRINTF */
 
 int
+#ifdef HAVE_STDARG_H /* Also ANSI-C .. */
+siofprintf(FILE *fp, char *fmt, ...)
+#else
 siofprintf(va_alist)
 	va_dcl
+#endif
 {
 	va_list ap;
+	int r;
+#ifdef HAVE_STDARG_H
+	va_start(ap,fmt);
+#else
 	FILE *fp;
 	char *fmt;
-	int r;
 
 	va_start(ap);
 	fp = va_arg(ap, FILE *);
 	fmt = va_arg(ap, char *);
+#endif
 	if (_FILEIO(fp))
 	  r = vfprintf(fp, fmt, ap);
 	else
@@ -177,15 +193,23 @@ siofprintf(va_alist)
 }
 
 int
+#ifdef HAVE_STDARG_H
+sioprintf(char *fmt, ...)
+#else
 sioprintf(va_alist)
 	va_dcl
+#endif
 {
 	va_list ap;
-	char *fmt;
 	int r;
+#ifdef HAVE_STDARG_H
+	va_start(ap, fmt);
+#else
+	char *fmt;
 
 	va_start(ap);
 	fmt = va_arg(ap, char *);
+#endif
 	if (_FILEIO(stdout))
 	  r = vfprintf(stdout, fmt, ap);
 	else
