@@ -354,7 +354,7 @@ s_pushstack(l, s)
 	char *s;
 {
 	struct conscell *d, *tmp;
-	int oval = stickymem;
+	memtypes oval = stickymem;
 
 	stickymem = MEM_MALLOC;
 	d = newstring((u_char *)strsave(s));
@@ -376,3 +376,9 @@ s_popstack(l)
 	s_free_tree(d);
 	return l;
 }
+
+struct conscell *
+newcell()
+{
+	return (struct conscell*)tmalloc(sizeof(struct conscell));
+}
