@@ -92,7 +92,9 @@ extern void setfreefd();
 extern void v_purge();
 
 
+#ifndef strchr
 extern char *strchr(), *strrchr();
+#endif
 
 
 struct shCmd fnctns[] = {
@@ -822,7 +824,7 @@ run_daemon(argc, argv)
 	for (i=0; i<ROUTERDIR_CNT; ++i) {
 		dirp[i] = NULL; dirs[i] = NULL;
 	}
-	/* dirp[0] = opendir(".");	/* assert dirp != NULL ... */
+	/* dirp[0] = opendir("."); */	/* assert dirp != NULL ... */
 #if 0
 #ifdef BSD
 	dirp[0]->dd_size = 0;	/* stupid Berkeley bug workaround */
@@ -890,7 +892,7 @@ run_daemon(argc, argv)
 		 * rewinddir() will find any new data from the
 		 * system...
 		 */
-		/* rewinddir(dirp[i]); /* some system w/o this ? */
+		/* rewinddir(dirp[i]); */	/* some system w/o this ? */
 
 #if 0
 #ifdef	BUGGY_CLOSEDIR
