@@ -6,7 +6,7 @@
 /* LINTLIBRARY */
 
 #include "mailer.h"
-#ifdef	USE_NDBM
+#ifdef	HAVE_NDBM_H
 #ifdef FCNTL_H
 # include FCNTL_H
 #endif
@@ -201,7 +201,7 @@ print_ndbm(sip, outfp)
 			continue;
 		if (dbm_error(db))
 			break;
-		if (*val.dptr == '\0')
+		if (*(char*)val.dptr == '\0')
 			fprintf(outfp, "%s\n", key.dptr);
 		else
 			fprintf(outfp, "%s\t%s\n", key.dptr, val.dptr);
@@ -253,20 +253,11 @@ owner_ndbm(sip, outfp)
 		return;
 	/* There are more timing hazards, when the internal fd is not
 	   available for probing.. */
-#if 1
-	/* No lstat()! */
-	if (stat(sip->file, &stbuf) < 0) {
-		fprintf(stderr, "owner_ndbm: cannot stat(\"%s\")!\n",
-				sip->file);
-		return;
-	}
-#else
-	if (fstat(dbm_pagfno(db), &stbuf) < 0) {
+	if (fstat(dbm_dirfno(db), &stbuf) < 0) {
 		fprintf(stderr, "owner_ndbm: cannot fstat(\"%s\")!\n",
 				sip->file);
 		return;
 	}
-#endif
 	fprintf(outfp, "%d\n", stbuf.st_uid);
 	fflush(outfp);
 }
@@ -284,19 +275,11 @@ modp_ndbm(sip)
 	if (sip->file == NULL
 	    || (db = open_ndbm(sip, O_RDONLY, "owner_ndbm")) == NULL)
 		return 0;
-#if 1
-	if (stat(sip->file, &stbuf) < 0) {
-		fprintf(stderr, "modp_ndbm: cannot stat(\"%s\")!\n",
-				sip->file);
-		return 0;
-	}
-#else
-	if (fstat(dbm_pagfno(db), &stbuf) < 0) {
+	if (fstat(dbm_dirfno(db), &stbuf) < 0) {
 		fprintf(stderr, "modp_ndbm: cannot fstat(\"%s\")!\n",
 				sip->file);
 		return 0;
 	}
-#endif
 	symid = symbol((u_char *)sip->file);
 	spl = sp_lookup(symid, spt_modcheck);
 	if (spl != NULL) {
@@ -308,4 +291,4 @@ modp_ndbm(sip)
 		   stbuf.st_nlink, spt_modcheck);
 	return rval;
 }
-#endif	/* USE_NDBM */
+#endif	/* HAVE_NDBM */
