@@ -49,6 +49,7 @@ extern int elink();
 extern int eunlink();
 extern int erename();
 extern int getline();
+extern int repos_getline();
 extern int nobody;
 extern int s_equal();
 extern long elseek();
@@ -61,6 +62,39 @@ static void	prctladdr __((struct conscell *info, FILE *fp, int cfflag, char *com
 static void	prdsndata __((struct conscell *info, FILE *fp, int cfflag, char *comment));
 static struct conscell	*find_errto __((struct conscell *list));
 
+#define dprintf	if (D_sequencer) printf
+
+#define	QCHANNEL(x)	(x)->string
+#define	QHOST(x)	(cdr(x))->string
+#define	QUSER(x)	(cddr(x))->string
+#define	QATTRIBUTES(x)	(cdr(cddr(x)))->string
+
+
+struct conscell *
+makequad()
+{
+	struct conscell *l, *tmp;
+
+	l = conststring(NULL);
+	cdr(l) = conststring(NULL);
+	cddr(l) = conststring(NULL);
+	cdr(cddr(l)) = conststring(NULL);
+	return l;
+}
+
+struct envelope *qate;
+
+int
+iserrmessage()
+{
+	return (qate != NULL
+		&& qate->e_from_trusted != NULL
+		&& (QCHANNEL(qate->e_from_trusted) == NULL
+		    || CISTREQ(QCHANNEL(qate->e_from_trusted), "error")));
+}
+
+
+
 /*
  * Apply RFC822 parsing and processing to the message in the file in argv[1].
  */
@@ -101,6 +135,7 @@ run_rfc822(argc, argv)
 	stickymem = MEM_TEMP;	/* per-message space */
 
 	e = (struct envelope *)tmalloc(sizeof (struct envelope));
+	qate = e;
 
 	if ((e->e_fp = fopen(file, "r")) == NULL) {
 		fprintf(stderr, "router: cannot open %s\n", file);
@@ -287,7 +322,7 @@ makeLetter(e, octothorp)
 				h->h_contents = hdr_scanparse(e, h, octothorp);
 				h->h_stamp = hdr_type(h);
 				return PERR_BADSUBMIT;
-				break;
+				/* break; */
 			case eFrom:		/* pity to break the elegance */
 				hd = h->h_descriptor;
 				osem = hd->semantics;
@@ -721,13 +756,6 @@ defer(e, why)
 #endif
 }
 
-#define dprintf	if (D_sequencer) printf
-
-#define	QCHANNEL(x)	(x)->string
-#define	QHOST(x)	(cdr(x))->string
-#define	QUSER(x)	(cddr(x))->string
-#define	QATTRIBUTES(x)	(cdr(cddr(x)))->string
-
 
 /*
  * Construct a header line that contains a given sender name.
@@ -1028,27 +1056,6 @@ thesender(e, a)
 	return CISTREQ(QUSER(e->e_from_resolved),uidpwnam(e->e_statbuf.st_uid));
 }
 
-struct conscell *
-makequad()
-{
-	struct conscell *l, *tmp;
-
-	l = conststring(NULL);
-	cdr(l) = conststring(NULL);
-	cddr(l) = conststring(NULL);
-	cdr(cddr(l)) = conststring(NULL);
-	return l;
-}
-
-static struct envelope *qate;
-
-int
-iserrmessage()
-{
-	return (qate != NULL
-		&& qate->e_from_trusted != NULL
-		&& CISTREQ(QCHANNEL(qate->e_from_trusted), "error"));
-}
 
 /*
  * The sequencer takes care of doing the right things with the right headers
@@ -1171,13 +1178,35 @@ sequencer(e, file)
 		envid = (char*)h->h_contents.a->a_pname;
 	}
 	FindEnvelope(eFrom);
+	if (h == NULL && e->e_trusted) {
+		/* Perhaps  'channel error' ??? */
+		FindEnvelope(eChannel);
+		if (h != NULL) {
+			dprintf("A channel was specified\n");
+			if ((ap = h->h_contents.a) != NULL
+			    && (p = ap->a_tokens) != NULL
+			    && p->p_tokens != NULL) {
+				t = p->p_tokens;
+				QCHANNEL(e->e_from_trusted) =
+					(u_char *)strnsave((char *)t->t_pname,
+							   TOKENLEN(t));
+			} else {
+				/*
+				 * No origination channel, or channel
+				 * has no name, or ...
+				 */
+				optsave(FYI_NOCHANNEL, e);
+			}
+		}
+	}
+
 	if (h == NULL) {
 		dprintf("A sender was NOT specified in the envelope\n");
 		for (h = e->e_headers; h != NULL; h = h->h_next)
 			if (h->h_descriptor->user_type == Sender
 			    && (e->e_resent == 0
 				|| h->h_descriptor->class == Resent))
-				break;
+			break;
 		if (h != NULL && e->e_trusted) {
 			dprintf("Use the Sender: or From: field from header\n");
 			h = copySender(e);
@@ -1235,6 +1264,7 @@ sequencer(e, file)
 	def_uid = nobody;
 
 	if (e->e_trusted) {
+		/* The sender uid is known */
 		FindEnvelope(eChannel);
 		if (h != NULL) {
 			dprintf("A channel was specified\n");
@@ -1281,6 +1311,14 @@ sequencer(e, file)
 				abort();
 			l = router(h->h_contents.a,
 				   e->e_statbuf.st_uid, "sender");
+			if (l == NULL) {
+			  /* From: <>,  and no envelope 'from' .. */
+			  h = mkSender(e,uidpwnam(e->e_statbuf.st_uid),0);
+			  if (h == NULL)
+			    abort();
+			  l = router(h->h_contents.a,
+				     e->e_statbuf.st_uid, "sender");
+			}
 			if (l != NULL) {
 				/*
 				 * In case the router returns several addresses,
@@ -1352,7 +1390,6 @@ sequencer(e, file)
 		QUSER(e->e_from_trusted) = QUSER(e->e_from_resolved);
 	if (QATTRIBUTES(e->e_from_trusted) == NULL)
 		QATTRIBUTES(e->e_from_trusted) =QATTRIBUTES(e->e_from_resolved);
-	qate = e;
 
 	dprintf("Recipient determination\n");
 	FindEnvelope(eTo);
