@@ -27,6 +27,14 @@ static void __free(ptr,file,line) void *ptr; char*file;int line; { fprintf(stder
 
 #endif
 
+
+#ifndef strchr /* IBM AIX is a bit peculiar.. these are macroes! */
+extern char *strcpy(), *strncpy(), *strcat();
+extern char *strchr(), *strrchr();
+#endif
+
+
+
 /* agenda.c */
 extern time_t qipcretry;
 extern int doagenda __((void));
@@ -134,4 +142,4 @@ extern char *saytime __((long, char *, int));
 extern void expire __((struct vertex *, int));
 
 /* Transport library */
-extern int lockaddr __((int, char *, long, char, char));
+/* extern int lockaddr __((int, char *, long, int, int)); */
