@@ -15,7 +15,7 @@
 # include <sys/statvfs.h>
 # define FSTATFS fstatvfs
 #else	/* !HAVE_STATVFS */
-#if defined(SYSV) || defined(RISC6000)
+#if defined(SYSV) || defined(_AIX)
 # include <sys/statfs.h>
 # define FSTATFS fstatfs /* Existence of this means (usually) SYSV code */
 #else /* Hmm.. Assuming it appears on all NON-SysV systems.. */
@@ -56,7 +56,7 @@ int fd;
 	}
 #else
 #if defined(__linux__) || (defined(BSD4_4) && !defined(bsdi)) || \
-    defined(ULTRIX) || defined(RISC6000)
+    defined(ULTRIX) || defined(_AIX)
 	struct statfs statbuf;
 	if ((rc = fstatfs(fd, &statbuf)) == 0) {
 	  availspace = statbuf.f_bavail * statbuf.f_bsize;
