@@ -74,7 +74,7 @@ extern int wait();
 # endif
 #endif
 
-#if	defined(HAVE_NETDB_H)
+#ifdef HAVE_NETDB_H
 # include <netdb.h>
 #endif
 #ifdef	HAVE_SYS_SOCKET_H
@@ -101,7 +101,7 @@ extern int wait();
  * when we are being run by the 4.2 inetd is included by defining
  * CHECK42INETD.  Should be deleted at the earliest possible opportunity.
  */
-/* #define	CHECK42INETD	/* heuristics to detect the 4.2 inetd */
+/* #define  CHECK42INETD */	/* heuristics to detect the 4.2 inetd */
 	/* [mea@utu.fi] - 4-Feb-95, I disabled this.. */
 
 typedef enum {	Null, Hello, Mail, MailOrHello, Recipient,
@@ -175,7 +175,7 @@ extern struct smtpconf *readcffile __(()), *findcf __(());
 struct smtpconf *cfhead = NULL;
 
 char	*progname, *cmdline, *eocmdline, *logfile;
-char	*postoffice = NULL;
+extern char *postoffice; /* Defined at mail.c -- mail_open() and friends */
 char	*routerprog = NULL;
 char	myhostname[MAXHOSTNAMELEN+1];
 char	rhostname[MAXHOSTNAMELEN+1];
@@ -278,7 +278,9 @@ extern int errno;
 extern int optind;
 extern char *optarg;
 
+#ifndef strchr
 extern char *strchr(), *strrchr();
+#endif
 extern int cistrcmp(), cistrncmp();
 
 #ifdef HAVE_STDARG_H
@@ -2669,6 +2671,7 @@ type821err(code,inbuf,msg,s1,s2,s3)
 	type(code,msg,s1,s2,s3);
 }
 
+static void header_to_mime __((char *, int *, int));
 static void header_to_mime(buf, lenptr, maxlen)
 	char *buf;
 	int *lenptr;
