@@ -12,6 +12,8 @@
 
 #include "hostenv.h"
 #include <stdio.h>
+#include <sys/types.h>
+#include <sys/stat.h>
 #include <sys/file.h>
 #include "mail.h"
 #include "ta.h"
@@ -28,7 +30,7 @@ lockaddr(fd, map, offset, was, new)
 	int	was;
 	int	new;
 {
-	char	lockbuf[1+_CFTAG_RCPTPIDSIZE+1];
+	char	lockbuf[/* 1+_CFTAG_RCPTPIDSIZE+1 */ 16]; /* Alpha alignments.. */
 	int	newlock = 0;
 
 #ifdef USE_FCNTLLOCK
