@@ -33,10 +33,13 @@
 # include <varargs.h>
 #endif
 #include <sys/types.h>
+#include <sys/stat.h>
 #include "ta.h"
 
 extern char *strdup();
+#ifndef strchr
 extern char *strchr();
+#endif
 extern void *emalloc();
 extern void *erealloc();
 
