@@ -263,7 +263,9 @@ extern int  qptext_check __((struct rcpt *rp));
 extern void hp_init();
 extern char **hp_getaddr();
 extern int errno;
+#ifndef strchr
 extern char *strchr(), *strrchr();
+#endif
 extern int  lstat(); /* remaps to  stat() if USE_LSTAT is not defined.. */
 extern FILE *fdopen();
 #ifndef MALLOC_TRACE
@@ -1576,7 +1578,7 @@ setupuidgid(rp, uid, gid)
 	  if (uid < 0 && atol(rp->addr->misc) < 0) {
 	    /* use magic non-sense +ve uid < MAXSHORT */
 	    rp->addr->misc = NONUIDSTR;
-	    return setupuidgid(rp, atol(NONUIDSTR), gid);
+	    return setupuidgid(rp, (uid_t)atoi(NONUIDSTR), gid);
 	  }
 	  DIAGNOSTIC(rp, EX_OSERR, "can't seteuid to %d", (int)uid);
 	  return 0;
@@ -2001,7 +2003,7 @@ writebuf(fp, buf, len, lastchp)
 		case 'm':	expect = ' '; break;
 		case ' ':
 		  /* Write the separator, and the word.. */
-		  if (fwrite(">From ", 6, 1, fp) < 0 || ferror(fp))
+		  if (fwrite(">From ", 6, 1, fp) == 0 || ferror(fp))
 		    { tlen = -1; break; }
 		  /* anticipate future instances */
 		  expect = '\0';
